# Constants
BASE_URL = "https://accounts.iot.findernet.com"
LOGIN_ENDPOINT = "/connect/token"
NEGOTIATE_URL = "https://bliss.iot.findernet.com/_sync/negotiate"
CLIENT_ID = "com.findernet.Bliss2"
CLIENT_UID = "95a351bb-3a31-4b21-8f06-cbdaa3d25882"
SCOPE = "openid offline_access profile email"
GRANT_TYPE = "password"
PING_INTERVAL = 15  # Ping every 15 seconds